import os as _os
_on_rtd = _os.environ.get('READTHEDOCS', None) == 'True'
if not _on_rtd:
    import numpy as _np


def linspacestep(start, stop, step=1):
    """
    Create a vector of values over an interval with a specified step size.

    Parameters
    ----------

    start : float
        The beginning of the interval.
    stop : float
        The end of the interval.
    step : float
        The step size.

    Returns
    -------
    vector : :class:`numpy.ndarray`
        The vector of values.
    """
    # Find an integer number of steps
    numsteps = _np.int((stop-start)/step)

    # Do a linspace over the new range
    # that has the correct endpoint
    return _np.linspace(start, start+step*numsteps, numsteps+1)



__all__ = [
    'LinLsqFit',
    'chisquare',
    'curve_fit_unscaled',
    'fft',
    'gaussfit'
    ]
__all__.sort()
from .LinLsqFit_mod import *                 # noqa
from .chisquare import *                 # noqa
from .curve_fit_unscaled import *        # noqa
from .fft import *                       # noqa
from .fill_missing_timestamps import *   # noqa
from .gaussfit import *                  # noqa

import os as _os
_on_rtd = _os.environ.get('READTHEDOCS', None) == 'True'
if not _on_rtd:
    import pyximport
    import numpy as _np
    pyximport.install(setup_args={"include_dirs": _np.get_include()})

    from .hough_ellipse import hough_ellipse



import os as _os
_on_rtd = _os.environ.get('READTHEDOCS', None) == 'True'
if not _on_rtd:
    import numpy as _np


def frexp10(x):
    """
    Finds the mantissa and exponent of a number :math:`x` such that :math:`x = m 10^e`.

    Parameters
    ----------

    x : float
        Number :math:`x` such that :math:`x = m 10^e`.

    Returns
    -------

    mantissa : float
        Number :math:`m` such that :math:`x = m 10^e`.
    exponent : float
        Number :math:`e` such that :math:`x = m 10^e`.
    """
    expon = _np.int(_np.floor(_np.log10(_np.abs(x))))
    mant = x/_np.power(10, expon)
    return (mant, expon)



# Author: Joel Frederico
"""
This project has slowly grown from frequently-used code snippets. The main objective is to create a collection of interconnected methods frequently needed to visualize and analyze data using `NumPy <http://www.numpy.org/>`_, `SciPy <http://www.scipy.org/>`_, `Matplotlib <http://matplotlib.org/>`_, and `PyQt4 <http://www.riverbankcomputing.com/software/pyqt/download>`_.
"""
__version__ = '1.11.1'
from . import accelphys
from . import facettools
from . import logging
from . import matplotlib
from . import numpy
from . import scipy
from . import utils
from . import PWFA



import os as _os
on_rtd = _os.environ.get('READTHEDOCS', None) == 'True'
if not on_rtd:
    import matplotlib.pyplot as _plt
    from matplotlib import gridspec as _gridspec


def setup_figure(rows=1, cols=1, **kwargs):
    """
    Sets up a figure with a number of rows (*rows*) and columns (*cols*), *\*\*kwargs* passes through to :class:`matplotlib.figure.Figure`.

    .. versionchanged:: 1.3
       Supports *\*\*kwargs* pass-through to :class:`matplotlib.figure.Figure`.
       
    .. versionchanged:: 1.2
       Changed *gridspec_x* to *rows*, *gridspec_y* to *cols*, added *figsize* control.

    Parameters
    ----------

    rows : int
        Number of rows to create.
    cols : int
        Number of columns to create.

    Returns
    -------
    
    fig : :class:`matplotlib.figure.Figure`
        The figure.
    gs : :class:`matplotlib.gridspec.GridSpec`
        Instance with *gridspec_x* rows and *gridspec_y* columns
    """
    fig = _plt.figure(**kwargs)
    gs = _gridspec.GridSpec(rows, cols)

    return fig, gs
